==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ClassIdentifierSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifier;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ClassIdentifierAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.List;


public class ClassIdentifierSetImpl extends InstanceSet<ClassIdentifierSet,ClassIdentifier> implements ClassIdentifierSet {

    // attributes
    @Override
    public void setOid_ID( int m_Oid_ID ) throws XtumlException {
        for ( ClassIdentifier classidentifier : this ) classidentifier.setOid_ID( m_Oid_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassIdentifier classidentifier : this ) classidentifier.setObj_ID( ref_Obj_ID );
    }


    // selections
    @Override
    public ModelClassSet R104_identifies_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ClassIdentifier classidentifier : this ) modelclassset.add( classidentifier.R104_identifies_ModelClass() );
        return modelclassset;
    }
    @Override
    public ClassIdentifierAttributeSet R105_is_made_up_of__ClassIdentifierAttribute() throws XtumlException {
        ClassIdentifierAttributeSet classidentifierattributeset = new ClassIdentifierAttributeSetImpl();
        for ( ClassIdentifier classidentifier : this ) classidentifierattributeset.addAll( classidentifier.R105_is_made_up_of__ClassIdentifierAttribute() );
        return classidentifierattributeset;
    }
    @Override
    public ReferredToClassInAssocSet R109_identifies_for_this_association__ReferredToClassInAssoc() throws XtumlException {
        ReferredToClassInAssocSet referredtoclassinassocset = new ReferredToClassInAssocSetImpl();
        for ( ClassIdentifier classidentifier : this ) referredtoclassinassocset.addAll( classidentifier.R109_identifies_for_this_association__ReferredToClassInAssoc() );
        return referredtoclassinassocset;
    }


    @Override
    public ClassIdentifier nullElement() {
        return ClassIdentifierImpl.EMPTY_CLASSIDENTIFIER;
    }

    @Override
    public ClassIdentifierSet emptySet() {
      return new ClassIdentifierSetImpl();
    }

    @Override
    public ClassIdentifierSet value() {
        return this;
    }

    @Override
    public List<ClassIdentifier> elements() {
        return Arrays.asList(toArray(new ClassIdentifier[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ClassIdentifierSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.ReferredToClassInAssocSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ReferredToClassInAssocSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifier;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierAttributeSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ClassIdentifierAttributeSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ClassIdentifierSetImpl extends InstanceSet<ClassIdentifierSet,ClassIdentifier> implements ClassIdentifierSet {

    public ClassIdentifierSetImpl() {
    }

    public ClassIdentifierSetImpl(Comparator<? super ClassIdentifier> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassIdentifier classidentifier : this ) classidentifier.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setOid_ID( int m_Oid_ID ) throws XtumlException {
        for ( ClassIdentifier classidentifier : this ) classidentifier.setOid_ID( m_Oid_ID );
    }


    // selections
    @Override
    public ModelClassSet R104_identifies_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ClassIdentifier classidentifier : this ) modelclassset.add( classidentifier.R104_identifies_ModelClass() );
        return modelclassset;
    }
    @Override
    public ClassIdentifierAttributeSet R105_is_made_up_of__ClassIdentifierAttribute() throws XtumlException {
        ClassIdentifierAttributeSet classidentifierattributeset = new ClassIdentifierAttributeSetImpl();
        for ( ClassIdentifier classidentifier : this ) classidentifierattributeset.addAll( classidentifier.R105_is_made_up_of__ClassIdentifierAttribute() );
        return classidentifierattributeset;
    }
    @Override
    public ReferredToClassInAssocSet R109_identifies_for_this_association__ReferredToClassInAssoc() throws XtumlException {
        ReferredToClassInAssocSet referredtoclassinassocset = new ReferredToClassInAssocSetImpl();
        for ( ClassIdentifier classidentifier : this ) referredtoclassinassocset.addAll( classidentifier.R109_identifies_for_this_association__ReferredToClassInAssoc() );
        return referredtoclassinassocset;
    }


    @Override
    public ClassIdentifier nullElement() {
        return ClassIdentifierImpl.EMPTY_CLASSIDENTIFIER;
    }

    @Override
    public ClassIdentifierSet emptySet() {
      return new ClassIdentifierSetImpl();
    }

    @Override
    public ClassIdentifierSet emptySet(Comparator<? super ClassIdentifier> comp) {
      return new ClassIdentifierSetImpl(comp);
    }

    @Override
    public ClassIdentifierSet value() {
        return this;
    }

    @Override
    public List<ClassIdentifier> elements() {
        return Arrays.asList(toArray(new ClassIdentifier[0]));
    }

}
